@@ -408,6 +408,9 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     char
       symbolic[MagickPathExtent];
 
+    MagickAddressType
+      value = (MagickAddressType) j;
+
     p=next;
     next=NextXPMLine(p);
     if (next == (char *) NULL)
@@ -415,7 +418,8 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     length=MagickMin((size_t) width,MagickPathExtent-1);
     if (CopyXPMColor(key,p,length) != (ssize_t) length)
       break;
-    status=AddValueToSplayTree(xpm_colors,ConstantString(key),(void *) j);
+    status=AddValueToSplayTree(xpm_colors,ConstantString(key),(const void *)
+      value);
     /*
       Parse color.
     */
